@@ -1,12 +1,16 @@
+#[macro_use]
+extern crate lazy_static;
+
 pub use capitalize::capitalize;
-pub use concat::{Concat, Join};
+pub use concat::{Concat, concat_lines, concat_lines_edged, contingent_lines, join};
 pub use str_value::str_value;
 pub use sub::sub;
 
+pub mod enums;
 pub mod chars;
 
 mod capitalize;
 mod str_value;
 mod sub;
-mod lines;
 mod concat;
+mod bracket;
\ No newline at end of file
